@@ -1,14 +1,17 @@
 package Log::ger::Format::None;
 
-our $DATE = '2019-05-06'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $DATE = '2020-02-18'; # DATE
+our $VERSION = '0.029'; # VERSION
 
 sub get_hooks {
     return {
         create_formatter => [
-            __PACKAGE__, 50,
-            sub {
-                [sub {shift}];
+            __PACKAGE__, # key
+            50,          # priority
+            sub {        # hook
+                my %hook_args = @_;
+                my $formatter = sub { shift };
+                [$formatter];
             }],
     };
 }
@@ -28,7 +31,7 @@ Log::ger::Format::None - Perform no formatting on the message
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
@@ -50,7 +53,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
