@@ -1,7 +1,7 @@
 package Log::ger::Output::String;
 
-our $DATE = '2019-05-06'; # DATE
-our $VERSION = '0.028'; # VERSION
+our $DATE = '2020-02-18'; # DATE
+our $VERSION = '0.029'; # VERSION
 
 use strict;
 use warnings;
@@ -19,8 +19,8 @@ sub get_hooks {
         create_log_routine => [
             __PACKAGE__, 50,
             sub {
-                my %args = @_;
-                my $level = $args{level};
+                my %hook_args = @_;
+                my $level = $hook_args{level};
                 my $logger = sub {
                     my $msg = $_[1];
                     if ($formatter) {
@@ -50,7 +50,7 @@ Log::ger::Output::String - Set output to a string
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
